@@ -1,5 +1,6 @@
 /*
  * Copyright 1994-2018 Brad Lanam, Walnut Creek, CA
+ * Copyright 2023 Brad Lanam, Pleasant Hill, CA
  */
 
 #include "config.h"
@@ -93,10 +94,11 @@ static void checkZone           _((diDiskInfo_t *, zoneInfo_t *, unsigned int));
 #endif
 static void checkIgnoreList     _((diDiskInfo_t *, iList_t *));
 static void checkIncludeList    _((diDiskInfo_t *, iList_t *));
-static int  isIgnoreFSType      _((char *));
-static int  isIgnoreSpecial     _((char *));
+static int  isIgnoreFSType      _((const char *));
+static int  isIgnoreSpecial     _((const char *));
+static int  isIgnoreFS          _((const char *, const char *));
 #if _lib_realpath && _define_S_ISLNK && _lib_lstat
-static int  checkForUUID        _((char *));
+static int  checkForUUID        _((const char *));
 #endif
 
 #if defined (__cplusplus) || defined (c_plusplus)
@@ -104,15 +106,7 @@ static int  checkForUUID        _((char *));
 #endif
 
 char *
-#if _proto_stdc
 dimainproc (int argc, const char * const argv [], int intfcflag, diData_t *diData)
-#else
-dimainproc (argc, argv, intfcflag, diData)
-    int         argc;
-    const char  * const argv [];
-    int         intfcflag;
-    diData_t    *diData;
-#endif
 {
     diOptions_t         *diopts;
     diOutput_t          *diout;
@@ -241,12 +235,7 @@ dimainproc (argc, argv, intfcflag, diData)
  */
 
 extern void
-#if _proto_stdc
 cleanup (diData_t *diData)
-#else
-cleanup (diData)
-    diData_t   *diData;
-#endif
 {
     if (diData->diskInfo != (diDiskInfo_t *) NULL)
     {
@@ -272,19 +261,11 @@ cleanup (diData)
 }
 
 extern int
-#if _proto_stdc
 checkFileInfo (
     diData_t *diData,
     int optidx,
     int argc,
     const char * const argv [])
-#else
-checkFileInfo (diData, optidx, argc, argv)
-    diData_t            *diData;
-    int                 optidx;
-    int                 argc;
-    const char          * const argv [];
-#endif
 {
     int                 rc;
     int                 i;
@@ -464,12 +445,7 @@ checkFileInfo (diData, optidx, argc, argv)
  */
 
 extern void
-#if _proto_stdc
 getDiskStatInfo (diData_t *diData)
-#else
-getDiskStatInfo (diData)
-    diData_t            *diData;
-#endif
 {
     int         i;
     struct stat statBuf;
@@ -515,13 +491,7 @@ getDiskStatInfo (diData)
  */
 
 extern int
-#if _proto_stdc
 getDiskSpecialInfo (diData_t *diData, unsigned int dontResolveSymlink)
-#else
-getDiskSpecialInfo (diData, dontResolveSymlink)
-    diData_t     *diData;
-    unsigned int dontResolveSymlink;
-#endif
 {
     int         i;
     struct stat statBuf;
@@ -591,13 +561,7 @@ getDiskSpecialInfo (diData, dontResolveSymlink)
  */
 
 extern void
-#if _proto_stdc
 checkDiskInfo (diData_t *diData, int hasLoop)
-#else
-checkDiskInfo (diData, hasLoop)
-    diData_t    *diData;
-    int         hasLoop;
-#endif
 {
     int             i;
     int             j;
@@ -684,7 +648,7 @@ checkDiskInfo (diData, hasLoop)
             dinfo->printFlag = DI_PRNT_IGNORE;
             dinfo->doPrint = (char) diopts->displayAll;
             if (debug > 2) {
-              printf ("chk: ignore-fs: %s\n", dinfo->name);
+              printf ("chk: ignore-fstype: %s\n", dinfo->fsType);
             }
           }
           if (isIgnoreSpecial (dinfo->special)) {
@@ -694,6 +658,13 @@ checkDiskInfo (diData, hasLoop)
               printf ("chk: ignore-special: %s\n", dinfo->special);
             }
           }
+          if (isIgnoreFS (dinfo->fsType, dinfo->name)) {
+            dinfo->printFlag = DI_PRNT_IGNORE;
+            dinfo->doPrint = (char) diopts->displayAll;
+            if (debug > 2) {
+              printf ("chk: ignore-fs: %s\n", dinfo->name);
+            }
+          }
 
           /* Some systems return a -1 or -2 as an indicator.    */
           if (dinfo->totalSpace == 0L ||
@@ -790,12 +761,7 @@ checkDiskInfo (diData, hasLoop)
 }
 
 extern void
-#if _proto_stdc
 checkDiskQuotas (diData_t *diData)
-#else
-checkDiskQuotas (diData)
-    diData_t            *diData;
-#endif
 {
   int           i;
   Uid_t         uid;
@@ -896,12 +862,7 @@ checkDiskQuotas (diData)
  */
 
 extern void
-#if _proto_stdc
 preCheckDiskInfo (diData_t *diData)
-#else
-preCheckDiskInfo (diData)
-    diData_t            *diData;
-#endif
 {
     int             i;
     diOptions_t     *diopts;
@@ -959,13 +920,7 @@ preCheckDiskInfo (diData)
 }
 
 static void
-#if _proto_stdc
 checkIgnoreList (diDiskInfo_t *diskInfo, iList_t *ignoreList)
-#else
-checkIgnoreList (diskInfo, ignoreList)
-    diDiskInfo_t     *diskInfo;
-    iList_t           *ignoreList;
-#endif
 {
     char            *ptr;
     int             i;
@@ -999,13 +954,7 @@ checkIgnoreList (diskInfo, ignoreList)
 }
 
 static void
-#if _proto_stdc
 checkIncludeList (diDiskInfo_t *diskInfo, iList_t *includeList)
-#else
-checkIncludeList (diskInfo, includeList)
-    diDiskInfo_t     *diskInfo;
-    iList_t           *includeList;
-#endif
 {
     char            *ptr;
     int             i;
@@ -1051,14 +1000,7 @@ checkIncludeList (diskInfo, includeList)
 
 #if _lib_zone_list && _lib_getzoneid && _lib_zone_getattr
 static void
-# if _proto_stdc
 checkZone (diDiskInfo_t *diskInfo, zoneInfo_t *zoneInfo, unsigned int allFlag)
-# else
-checkZone (diskInfo, zoneInfo, allFlag)
-    diDiskInfo_t *diskInfo;
-    zoneInfo_t   *zoneInfo;
-    unsigned int allFlag;
-# endif
 {
     int         i;
     int         idx = { -1 };
@@ -1160,11 +1102,7 @@ checkZone (diskInfo, zoneInfo, allFlag)
 #endif
 
 extern void
-#if _proto_stdc
 initLocale (void)
-#else
-initLocale ()
-#endif
 {
 #if _enable_nls
   const char      *localeptr;
@@ -1183,12 +1121,7 @@ initLocale ()
 }
 
 extern void
-#if _proto_stdc
 initZones (diData_t *diData)
-#else
-initZones (diData)
-  diData_t      *diData;
-#endif
 {
 #if _lib_zone_list && _lib_getzoneid && _lib_zone_getattr
   diData->zoneInfo.uid = geteuid ();
@@ -1273,12 +1206,7 @@ initZones (diData)
 }
 
 static int
-#if _proto_stdc
-isIgnoreSpecial (char *special)
-#else
-isIgnoreSpecial (special)
-  char      *special;
-#endif
+isIgnoreSpecial (const char *special)
 {
   static char   *appletimemachine = "com.apple.TimeMachine.";
 
@@ -1294,12 +1222,19 @@ isIgnoreSpecial (special)
 }
 
 static int
-#if _proto_stdc
-isIgnoreFSType (char *fstype)
-#else
-isIgnoreFSType (fstype)
-  char      *fstype;
-#endif
+isIgnoreFS (const char *fstype, const char *name)
+{
+  static char   *applesystem = "/System/";
+
+  if (strcmp (fstype, "apfs") == 0 &&
+       strncmp (name, applesystem, strlen(applesystem)) == 0) {
+    return TRUE;
+  }
+  return FALSE;
+}
+
+static int
+isIgnoreFSType (const char *fstype)
 {
   if (strcmp (fstype, "rootfs") == 0 ||
       strcmp (fstype, "procfs") == 0 ||
@@ -1314,12 +1249,7 @@ isIgnoreFSType (fstype)
 
 #if _lib_realpath && _define_S_ISLNK && _lib_lstat
 static int
-# if _proto_stdc
-checkForUUID (char *spec)
-# else
-checkForUUID (spec)
-  char      *spec;
-# endif
+checkForUUID (const char *spec)
 {
 /*
  *  /dev/mapper/luks-828fc648-9f30-43d8-a0b1-f7196a2edb66
