@@ -1,10 +1,11 @@
-/*
- * Copyright 2011-2018 Brad Lanam, Walnut Creek, CA
- */
-
 #ifndef DI_INC_GETOPTN_H_
 #define DI_INC_GETOPTN_H_
 
+/*
+ * Copyright 2011-2018 Brad Lanam, Walnut Creek, CA
+ * Copyright 2023 Brad Lanam, Pleasant Hill, CA
+ */
+
 #if defined(TEST_GETOPTN)
 # include "gconfig.h"
 #else
@@ -56,7 +57,7 @@ typedef struct {
   void          *value2;
 } getoptn_opt_t;
 
-extern int getoptn _((int style, int argc, const char * const argv [],
-      Size_t optcount, getoptn_opt_t opts [], int *errorCount));
+extern int getoptn (int style, int argc, const char * const argv [],
+      Size_t optcount, getoptn_opt_t opts [], int *errorCount);
 
 #endif /*DI_INC_GETOPTN_H_ */
