@@ -1,6 +1,10 @@
 #ifndef DI_INC_OPTIONS_H
 #define DI_INC_OPTIONS_H
 
+/*
+ * Copyright 2023 Brad Lanam, Pleasant Hill, CA
+ */
+
 #include "config.h"
 #include "di.h"
 
@@ -26,7 +30,7 @@
    extern "C" {
 # endif
 
-extern int getDIOptions _((int , const char * const [], diData_t *));
+extern int getDIOptions (int , const char * const [], diData_t *);
 
 # if defined (__cplusplus) || defined (c_plusplus)
    }
