@@ -1,5 +1,6 @@
 /*
  * Copyright 1994-2018 Brad Lanam, Walnut Creek, CA
+ * Copyright 2023 Brad Lanam, Pleasant Hill, CA
  */
 
 #include "config.h"
@@ -29,13 +30,7 @@
  */
 
 _pvoid
-#if _proto_stdc
 di_realloc (_pvoid ptr, Size_t size)
-#else
-di_realloc (ptr, size)
-    _pvoid      ptr;
-    Size_t      size;
-#endif
 {
     if (ptr == (_pvoid) NULL)
     {
