@@ -1,5 +1,6 @@
 /*
  * Copyright 1994-2018 Brad Lanam, Walnut Creek, CA
+ * Copyright 2023 Brad Lanam, Pleasant Hill, CA
  */
 
 #include "config.h"
@@ -19,13 +20,7 @@
 #endif
 
 void
-#if _proto_stdc
 trimChar (char *str, int ch)
-#else
-trimChar (str, ch)
-    char         *str;
-    int          ch;
-#endif
 {
   int     len;
 
