@@ -1,6 +1,7 @@
 #!/bin/sh
 #
 # Copyright 2020 Brad Lanam Pleasant Hill CA USA
+# Copyright 2020 Brad Lanam Pleasant Hill CA
 #
 
 if [ "${_MKCONFIG_DIR}" = "" ]; then
@@ -19,8 +20,10 @@ fi
 doshelltest $0 $@
 
 puts "$shell $shvers"
-puts "printf: $shhasprintf"
+puts "printf: $shhasprintf ($shhasprintferr)"
 puts "append: $shhasappend"
-puts "math: $shhasmath"
+puts "math: $shhasmath ($shhasmatherr)"
 puts "typeset -u: $shhasupper"
 puts "typeset -l: $shhaslower"
+puts "readraw required: $shreqreadraw"
+
