@@ -1,6 +1,7 @@
 #!/bin/sh
 #
 # Copyright 2011-2018 Brad Lanam Walnut Creek, CA, USA
+# Copyright 2020 Brad Lanam Pleasant Hill CA
 #
 
 maindodisplay () {
@@ -125,6 +126,8 @@ chkgrep () {
   arg=$3
   arg2=$4
 
+echo "chkgrep: pwd: `pwd`"
+echo "chkgrep: fn: $fn"
   if [ "$arg" = "wc" ]; then
     tl=`egrep -l "$pat" ${fn} 2>/dev/null | wc -l`
     rc=$?
@@ -160,7 +163,7 @@ chkoutd () {
 chkcache () {
   xp=$1
   shift
-  chkgrep "$xp" mkconfig.cache $@
+  chkgrep "$xp" ${MKC_FILES}/mkconfig.cache $@
 }
 
 chkenv () {
@@ -171,12 +174,12 @@ chkenv () {
 
 testcleanup () {
   if [ "$stag" != "none" ]; then
-    for x in out.h out.d testouth.c opts test.env mkconfig.log \
-        mkconfig.cache mkconfig.reqlibs c.env \
-	mkc_none_mkc.vars mkc_none_c.vars mkc_out_c.vars mkc_out_d.vars \
-	mkc_none_env.vars \
+    for x in out.h out.d testouth.c opts test.env c.env \
+	mkc_files \
 	$@; do
+      # test -e is not supported by older shells.
       test -f ${x} && mv ${x} ${x}${stag}
+      test -d ${x} && mv ${x} ${x}${stag}
     done
   fi
 }
