@@ -1,6 +1,7 @@
 #!/bin/sh
 #
 # Copyright 2010-2018 Brad Lanam Walnut Creek CA USA
+# Copyright 2020 Brad Lanam Pleasant Hill CA
 #
 #
 # check and see if there is a conflict between include files.
@@ -64,7 +65,7 @@ check_include_conflict () {
 
       code="#include <${h1}>
 #include <${h2}>
-main () { return 0; }
+int main () { return 0; }
 "
       do_c_check_compile "${name}" "${code}" std
     else
