@@ -1,6 +1,7 @@
 #!/bin/sh
 #
 # Copyright 2010-2018 Brad Lanam Walnut Creek, CA USA
+# Copyright 2020 Brad Lanam Pleasant Hill CA
 #
 
 #
@@ -140,3 +141,9 @@ check_system () {
     setdata ${_MKCONFIG_PREFIX} _MKCONFIG_SYSARCH "${_MKCONFIG_SYSARCH}"
   fi
 }
+
+check_standard_system () {
+  check_system system type
+  check_system system rev
+  check_system system arch
+}
